@@ -43,9 +43,31 @@ class RollupClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes an existing rollup job.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-delete-job.html>`_
+          <p>Delete a rollup job.</p>
+          <p>A job must be stopped before it can be deleted.
+          If you attempt to delete a started job, an error occurs.
+          Similarly, if you attempt to delete a nonexistent job, an exception occurs.</p>
+          <p>IMPORTANT: When you delete a job, you remove only the process that is actively monitoring and rolling up data.
+          The API does not delete any previously rolled up data.
+          This is by design; a user may wish to roll up a static data set.
+          Because the data set is static, after it has been fully rolled up there is no need to keep the indexing rollup job around (as there will be no new data).
+          Thus the job can be deleted, leaving behind the rolled up data for analysis.
+          If you wish to also remove the rollup data and the rollup index contains the data for only a single job, you can delete the whole rollup index.
+          If the rollup index stores data from several jobs, you must issue a delete-by-query that targets the rollup job's identifier in the rollup index. For example:</p>
+          <pre><code>POST my_rollup_index/_delete_by_query
+          {
+            &quot;query&quot;: {
+              &quot;term&quot;: {
+                &quot;_rollup.id&quot;: &quot;the_rollup_job_id&quot;
+              }
+            }
+          }
+          </code></pre>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-delete-job>`_
 
         :param id: Identifier for the job.
         """
@@ -84,9 +106,16 @@ class RollupClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves the configuration, stats, and status of rollup jobs.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-job.html>`_
+          <p>Get rollup job information.
+          Get the configuration, stats, and status of rollup jobs.</p>
+          <p>NOTE: This API returns only active (both <code>STARTED</code> and <code>STOPPED</code>) jobs.
+          If a job was created, ran for a while, then was deleted, the API does not return any details about it.
+          For details about a historical rollup job, the rollup capabilities API may be more useful.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-jobs>`_
 
         :param id: Identifier for the rollup job. If it is `_all` or omitted, the API
             returns all rollup jobs.
@@ -129,10 +158,20 @@ class RollupClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns the capabilities of any rollup jobs that have been configured for a specific
-        index or index pattern.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-rollup-caps.html>`_
+          <p>Get the rollup job capabilities.
+          Get the capabilities of any rollup jobs that have been configured for a specific index or index pattern.</p>
+          <p>This API is useful because a rollup job is often configured to rollup only a subset of fields from the source index.
+          Furthermore, only certain aggregations can be configured for various fields, leading to a limited subset of functionality depending on that configuration.
+          This API enables you to inspect an index and determine:</p>
+          <ol>
+          <li>Does this index have associated rollup data somewhere in the cluster?</li>
+          <li>If yes to the first question, what fields were rolled up, what aggregations can be performed, and where does the data live?</li>
+          </ol>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-rollup-caps>`_
 
         :param id: Index, indices or index-pattern to return rollup capabilities for.
             `_all` may be used to fetch rollup capabilities from all jobs.
@@ -175,10 +214,18 @@ class RollupClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns the rollup capabilities of all jobs inside of a rollup index (for example,
-        the index where rollup data is stored).
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-rollup-index-caps.html>`_
+          <p>Get the rollup index capabilities.
+          Get the rollup capabilities of all jobs inside of a rollup index.
+          A single rollup index may store the data for multiple rollup jobs and may have a variety of capabilities depending on those jobs. This API enables you to determine:</p>
+          <ul>
+          <li>What jobs are stored in an index (or indices specified via a pattern)?</li>
+          <li>What target indices were rolled up, what fields were used in those rollups, and what aggregations can be performed on each job?</li>
+          </ul>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-rollup-index-caps>`_
 
         :param index: Data stream or index to check for rollup capabilities. Wildcard
             (`*`) expressions are supported.
@@ -239,9 +286,16 @@ class RollupClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates a rollup job.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-put-job.html>`_
+          <p>Create a rollup job.</p>
+          <p>WARNING: From 8.15.0, calling this API in a cluster with no rollup usage will fail with a message about the deprecation and planned removal of rollup features. A cluster needs to contain either a rollup job or a rollup index in order for this API to be allowed to run.</p>
+          <p>The rollup job configuration contains all the details about how the job should run, when it indexes documents, and what future queries will be able to run against the rollup index.</p>
+          <p>There are three main sections to the job configuration: the logistical details about the job (for example, the cron schedule), the fields that are used for grouping, and what metrics to collect for each group.</p>
+          <p>Jobs are created in a <code>STOPPED</code> state. You can start them with the start rollup jobs API.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-put-job>`_
 
         :param id: Identifier for the rollup job. This can be any alphanumeric string
             and uniquely identifies the data that is associated with the rollup job.
@@ -356,14 +410,33 @@ class RollupClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Enables searching rolled-up data using the standard Query DSL.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-search.html>`_
+          <p>Search rolled-up data.
+          The rollup search endpoint is needed because, internally, rolled-up documents utilize a different document structure than the original data.
+          It rewrites standard Query DSL into a format that matches the rollup documents then takes the response and rewrites it back to what a client would expect given the original query.</p>
+          <p>The request body supports a subset of features from the regular search API.
+          The following functionality is not available:</p>
+          <p><code>size</code>: Because rollups work on pre-aggregated data, no search hits can be returned and so size must be set to zero or omitted entirely.
+          <code>highlighter</code>, <code>suggestors</code>, <code>post_filter</code>, <code>profile</code>, <code>explain</code>: These are similarly disallowed.</p>
+          <p>For more detailed examples of using the rollup search API, including querying rolled-up data only or combining rolled-up and live data, refer to the External documentation.</p>
 
-        :param index: Enables searching rolled-up data using the standard Query DSL.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-rollup-search>`_
+
+        :param index: A comma-separated list of data streams and indices used to limit
+            the request. This parameter has the following rules: * At least one data
+            stream, index, or wildcard expression must be specified. This target can
+            include a rollup or non-rollup index. For data streams, the stream's backing
+            indices can only serve as non-rollup indices. Omitting the parameter or using
+            `_all` are not permitted. * Multiple non-rollup indices may be specified.
+            * Only one rollup index may be specified. If more than one are supplied,
+            an exception occurs. * Wildcard expressions (`*`) may be used. If they match
+            more than one rollup index, an exception occurs. However, you can use an
+            expression to match multiple non-rollup indices or data streams.
         :param aggregations: Specifies aggregations.
         :param aggs: Specifies aggregations.
-        :param query: Specifies a DSL query.
+        :param query: Specifies a DSL query that is subject to some limitations.
         :param rest_total_hits_as_int: Indicates whether hits.total should be rendered
             as an integer or an object in the rest search response
         :param size: Must be zero if set, as rollups work on pre-aggregated data.
@@ -420,9 +493,14 @@ class RollupClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Starts an existing, stopped rollup job.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-start-job.html>`_
+          <p>Start rollup jobs.
+          If you try to start a job that does not exist, an exception occurs.
+          If you try to start a job that is already started, nothing happens.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-start-job>`_
 
         :param id: Identifier for the rollup job.
         """
@@ -463,14 +541,28 @@ class RollupClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Stops an existing, started rollup job.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-stop-job.html>`_
+          <p>Stop rollup jobs.
+          If you try to stop a job that does not exist, an exception occurs.
+          If you try to stop a job that is already stopped, nothing happens.</p>
+          <p>Since only a stopped job can be deleted, it can be useful to block the API until the indexer has fully stopped.
+          This is accomplished with the <code>wait_for_completion</code> query parameter, and optionally a timeout. For example:</p>
+          <pre><code>POST _rollup/job/sensor/_stop?wait_for_completion=true&amp;timeout=10s
+          </code></pre>
+          <p>The parameter blocks the API call from returning until either the job has moved to STOPPED or the specified time has elapsed.
+          If the specified time elapses without the job moving to STOPPED, a timeout exception occurs.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-stop-job>`_
 
         :param id: Identifier for the rollup job.
         :param timeout: If `wait_for_completion` is `true`, the API blocks for (at maximum)
             the specified duration while waiting for the job to stop. If more than `timeout`
-            time has passed, the API throws a timeout exception.
+            time has passed, the API throws a timeout exception. NOTE: Even if a timeout
+            occurs, the stop request is still processing and eventually moves the job
+            to STOPPED. The timeout simply means the API call itself timed out while
+            waiting for the status change.
         :param wait_for_completion: If set to `true`, causes the API to block until the
             indexer state completely stops. If set to `false`, the API returns immediately
             and the indexer is stopped asynchronously in the background.
